import math

def time_menu():
    print("Time Calculator")
    print("1: t = (vf - vi) / a")
    print("2: Solve s = vi*t + 0.5*a*t^2 (Quadratic Equation)")
    print("3: t = (2*s) / (vi + vf)   (using average velocity)")
    print("4: Angular Time: t = (ωf - ωi) / α")
    print("5: Free Fall: t = sqrt(2h/g)")
    print("6: Projectile Motion (Time of Flight): t = (2 * v0 * sin(θ)) / g")
    print("7: Oscillation Period (Mass-Spring): T = 2π * sqrt(m/k)")
    print("8: Circular Motion Period: T = 2π / ω")
    choice = input("Choose a method (1-8): ")
    return choice

def time_from_acceleration():
    # t = (vf - vi) / a
    vi = float(input("Enter initial velocity (vi): "))
    vf = float(input("Enter final velocity (vf): "))
    a = float(input("Enter acceleration (a): "))
    if a == 0:
        print("Acceleration cannot be zero for this formula.")
        return
    t = (vf - vi) / a
    print("Time (t) =", t)

def time_from_kinematics():
    # Solve: s = vi*t + 0.5*a*t^2  --> 0.5*a*t^2 + vi*t - s = 0
    print("Solve for t in s = vi*t + 0.5*a*t^2")
    s = float(input("Enter displacement (s): "))
    vi = float(input("Enter initial velocity (vi): "))
    a = float(input("Enter acceleration (a): "))
    
    if abs(a) < 1e-10:
        # When acceleration is zero, equation reduces to vi*t = s.
        if vi == 0:
            print("Both acceleration and initial velocity are zero. Cannot solve for time.")
            return
        t = s / vi
        print("Acceleration is zero. Time (t) =", t)
        return
    
    A = 0.5 * a
    B = vi
    C = -s
    discriminant = B**2 - 4 * A * C
    if discriminant < 0:
        print("No real solution for time (discriminant is negative).")
        return
    
    sqrt_disc = math.sqrt(discriminant)
    t1 = (-B + sqrt_disc) / (2 * A)
    t2 = (-B - sqrt_disc) / (2 * A)
    
    print("Possible time solutions:")
    print("t1 =", t1)
    print("t2 =", t2)

def time_from_average_velocity():
    # Using: s = ((vi + vf)/2)*t  -->  t = (2*s)/(vi + vf)
    print("Solve for t in s = ((vi + vf)/2) * t")
    s = float(input("Enter displacement (s): "))
    vi = float(input("Enter initial velocity (vi): "))
    vf = float(input("Enter final velocity (vf): "))
    
    avg_vel = (vi + vf) / 2
    if avg_vel == 0:
        print("Average velocity is zero, cannot compute time.")
        return
    t = s / avg_vel
    print("Time (t) =", t)

def angular_time():
    # For rotational motion: t = (ωf - ωi) / α
    wi = float(input("Enter initial angular velocity (ωi): "))
    wf = float(input("Enter final angular velocity (ωf): "))
    alpha = float(input("Enter angular acceleration (α): "))
    if alpha == 0:
        print("Angular acceleration cannot be zero for this formula.")
        return
    t = (wf - wi) / alpha
    print("Time (t) =", t)

def free_fall_time():
    # For free fall: t = sqrt(2h/g)
    h = float(input("Enter height (h): "))
    g = float(input("Enter gravitational acceleration (g) [~9.81 m/s^2]: "))
    if g <= 0:
        print("Gravitational acceleration must be positive.")
        return
    t = math.sqrt((2 * h) / g)
    print("Free fall time (t) =", t)

def projectile_time():
    # For projectile motion (assuming launch and landing at the same height):
    # t = (2*v0*sin(θ))/g  (θ in degrees)
    v0 = float(input("Enter initial velocity (v0): "))
    theta_deg = float(input("Enter launch angle (θ in degrees): "))
    theta_rad = math.radians(theta_deg)
    g = float(input("Enter gravitational acceleration (g) [~9.81 m/s^2]: "))
    if g <= 0:
        print("Gravitational acceleration must be positive.")
        return
    t = (2 * v0 * math.sin(theta_rad)) / g
    print("Time of flight (t) =", t)

def oscillation_period():
    # For a mass-spring system: T = 2π * sqrt(m/k)
    m = float(input("Enter mass (m): "))
    k = float(input("Enter spring constant (k): "))
    if k <= 0:
        print("Spring constant must be positive.")
        return
    T = 2 * math.pi * math.sqrt(m / k)
    print("Oscillation period (T) =", T)

def circular_motion_period():
    # For circular motion: T = 2π / ω
    omega = float(input("Enter angular velocity (ω): "))
    if omega == 0:
        print("Angular velocity cannot be zero for this formula.")
        return
    T = 2 * math.pi / omega
    print("Circular motion period (T) =", T)

def main():
    choice = time_menu()
    
    if choice == '1':
        time_from_acceleration()
    elif choice == '2':
        time_from_kinematics()
    elif choice == '3':
        time_from_average_velocity()
    elif choice == '4':
        angular_time()
    elif choice == '5':
        free_fall_time()
    elif choice == '6':
        projectile_time()
    elif choice == '7':
        oscillation_period()
    elif choice == '8':
        circular_motion_period()
    else:
        print("Invalid choice.")

# Call main automatically so you don't have to type it in.
main()
